
Ensure overall security
-------

**Description:**

Some parts of the application at first sight might seem to acquire a higher level of 
security than i.e unauthorised/public parts of the application. 
This however is not true since breaching public parts could also lead to an attacker 
compromising the application or other users accounts.

**Solution:**

Always ensure full hardened security on all layers of the web application.

Recommended knowledge-base item:

- High level architecture should be defined